var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __reExport = (target, mod, secondTarget) => (__copyProps(target, mod, "default"), secondTarget && __copyProps(secondTarget, mod, "default"));

// node_modules/@girs/gnome-shell/dist/extensions/extension.js
var extension_exports = {};
__reExport(extension_exports, extension_star);
import * as extension_star from "resource:///org/gnome/shell/extensions/extension.js";

// node_modules/@girs/gnome-shell/dist/ui/main.js
var main_exports = {};
__reExport(main_exports, main_star);
import * as main_star from "resource:///org/gnome/shell/ui/main.js";

// node_modules/@girs/gnome-shell/dist/ui/panelMenu.js
var panelMenu_exports = {};
__reExport(panelMenu_exports, panelMenu_star);
import * as panelMenu_star from "resource:///org/gnome/shell/ui/panelMenu.js";

// node_modules/@girs/gnome-shell/dist/ui/popupMenu.js
var popupMenu_exports = {};
__reExport(popupMenu_exports, popupMenu_star);
import * as popupMenu_star from "resource:///org/gnome/shell/ui/popupMenu.js";

// src/Player.ts
import GLib from "gi://GLib";
import Gio from "gi://Gio";
var Player = class {
  constructor(_settings) {
    this._settings = _settings;
  }
  _mpvSocket = "/tmp/quicklofi-socket";
  _isCommandRunning = false;
  _process = null;
  init() {
    this._settings.connect("changed::volume", (settings, key) => {
      if (this._process !== null && !this._isCommandRunning) {
        const volume = settings.get_int(key);
        const command = this.createCommand({
          command: ["set_property", "volume", volume]
        });
        this.sendCommandToMpvSocket(command);
      }
    });
  }
  stopPlayer() {
    if (this._process !== null) {
      this._process.force_exit();
      this._process = null;
      return;
    }
  }
  startPlayer(radio) {
    this.stopPlayer();
    try {
      const [, argv] = GLib.shell_parse_argv(
        `mpv --volume=${this._settings.get_int("volume")} --input-ipc-server=/tmp/quicklofi-socket --loop-playlist=force --no-video --ytdl-format='best*[vcodec=none]' --ytdl-raw-options-add='force-ipv4=' ${radio.radioUrl}`
      );
      this._process = Gio.Subprocess.new(argv, Gio.SubprocessFlags.NONE);
    } catch (e) {
      this._process = null;
      main_exports.default.notifyError(
        "MPV not found",
        "Did you have mpv installed?\nhttps://github.com/EuCaue/gnome-shell-extension-quick-lofi?tab=readme-ov-file#dependencies"
      );
    }
  }
  createCommand(command) {
    const cmd = `echo '${JSON.stringify(command)}'`;
    return cmd;
  }
  sendCommandToMpvSocket(mpvCommand) {
    this._isCommandRunning = true;
    const socatCommand = ["|", "socat", "-", this._mpvSocket];
    const [success, _] = GLib.spawn_async(
      null,
      ["/bin/sh", "-c", mpvCommand + " " + socatCommand.join(" ")],
      null,
      GLib.SpawnFlags.SEARCH_PATH,
      null
    );
    this._isCommandRunning = false;
    if (!success) {
      main_exports.default.notifyError(
        "Socat not found",
        "Did you have socat installed?\nhttps://github.com/EuCaue/gnome-shell-extension-quick-lofi?tab=readme-ov-file#dependencies"
      );
    }
  }
};

// src/Utils.ts
var Utils = class {
  static ICONS = {
    INDICATOR_DEFAULT: "/icon-symbolic.svg",
    INDICATOR_PLAYING: "/icon-playing-symbolic.svg",
    POPUP_PLAY: "media-playback-start-symbolic",
    POPUP_PAUSE: "media-playback-stop-symbolic"
  };
  static debug(...message) {
    console.log("[ QUICK LOFI DEBUG ] >>> ", ...message);
  }
};

// src/extension.ts
import GObject from "gi://GObject";
import Gio2 from "gi://Gio";
import St from "gi://St";
var _Indicator = class _Indicator extends panelMenu_exports.Button {
  mpvPlayer;
  _activeRadioPopupItem = null;
  _radios;
  _settings;
  _icon;
  _extension;
  constructor(ext) {
    super(0, "Quick Lofi");
    this._extension = ext;
    this.mpvPlayer = new Player(this._extension.getSettings());
    this.mpvPlayer.init();
    this._radios = [];
    const gicon = Gio2.icon_new_for_string(this._extension.path + Utils.ICONS.INDICATOR_DEFAULT);
    this._icon = new St.Icon({
      gicon,
      styleClass: "system-status-icon",
      iconSize: 20
    });
    this.add_child(this._icon);
    this._createRadios();
    this._connectSettingsChangedEvent();
    this._createMenuItems();
    this._handleButtonClick();
  }
  _createRadios() {
    const radios = this._extension.getSettings().get_strv("radios");
    radios.forEach((entry) => {
      const [radioName, radioUrl] = entry.split(" - ");
      this._radios.push({ radioName, radioUrl });
    });
  }
  _connectSettingsChangedEvent() {
    this._settings = this._extension.getSettings();
    this._settings.connect("changed", (_, key) => {
      if (key === "radios") {
        this._updateMenuItems();
      }
    });
  }
  _updateIcon(playing) {
    const extPath = this._extension.path;
    const iconPath = `${extPath}/${playing ? Utils.ICONS.INDICATOR_PLAYING : Utils.ICONS.INDICATOR_DEFAULT}`;
    const gicon = Gio2.icon_new_for_string(iconPath);
    this._icon.set_gicon(gicon);
  }
  _togglePlayingStatus(child) {
    const currentRadio = this._radios.find((radio) => radio.radioName === child.label.text);
    if (child === this._activeRadioPopupItem) {
      this.mpvPlayer.stopPlayer();
      this._activeRadioPopupItem.setIcon(Gio2.icon_new_for_string(Utils.ICONS.POPUP_PLAY));
      this._activeRadioPopupItem = null;
      this._updateIcon(false);
    } else {
      if (this._activeRadioPopupItem) {
        this._activeRadioPopupItem.setIcon(Gio2.icon_new_for_string(Utils.ICONS.POPUP_PLAY));
        this._updateIcon(false);
      }
      this.mpvPlayer.startPlayer(currentRadio);
      this._activeRadioPopupItem = child;
      child.setIcon(Gio2.icon_new_for_string(Utils.ICONS.POPUP_PAUSE));
      this._updateIcon(true);
    }
  }
  _handleButtonClick() {
    this.connect("button-press-event", (_, event) => {
      const RIGHT_CLICK = 3;
      if (event.get_button() === RIGHT_CLICK) {
        this.menu.close(false);
        this._extension.openPreferences();
        return;
      }
    });
  }
  _updateMenuItems() {
    this.menu.box.remove_all_children();
    this._radios = [];
    this._createRadios();
    this._createMenuItems();
  }
  _createMenuItems() {
    const scrollView = new St.ScrollView();
    const section1 = new popupMenu_exports.PopupMenuSection();
    scrollView.add_child(section1.actor);
    this._radios.forEach((radio) => {
      const menuItem = new popupMenu_exports.PopupImageMenuItem(
        radio.radioName,
        Gio2.icon_new_for_string(Utils.ICONS.POPUP_PLAY)
      );
      menuItem.connect("activate", this._togglePlayingStatus.bind(this));
      section1.addMenuItem(menuItem);
    });
    this.menu.box.add_child(scrollView);
    this.menu.box.style = `
        max-height: 12em;
    `;
  }
};
GObject.registerClass(_Indicator);
var Indicator = _Indicator;
var QuickLofi = class extends extension_exports.Extension {
  _indicator = null;
  _settings = null;
  constructor(props) {
    super(props);
  }
  _removeIndicator() {
    Utils.debug("extension disabled");
    this._indicator?.mpvPlayer.stopPlayer();
    this._indicator.destroy();
    this._indicator = null;
    this._settings = null;
  }
  enable() {
    Utils.debug("extension enabled");
    this._settings = this.getSettings();
    this._indicator = new Indicator(this);
    main_exports.panel.addToStatusArea(this.uuid, this._indicator);
  }
  disable() {
    this._removeIndicator();
  }
};
export {
  QuickLofi as default
};
